import type { AwsIdentityProperties } from "@aws-sdk/types";
import { FromSsoInit } from "./fromSso";
/**
 * Returns a SSOOIDC client for the given region.
 * @internal
 */
export declare const getSsoOidcClient: (ssoRegion: string, init?: FromSsoInit, callerClientConfig?: AwsIdentityProperties["callerClientConfig"]) => Promise<import("@aws-sdk/nested-clients/sso-oidc").SSOOIDCClient>;
