import {
  CredentialProviderOptions,
  TokenIdentityProvider,
} from "@aws-sdk/types";
export interface FromEnvSigningNameInit extends CredentialProviderOptions {
  signingName?: string;
}
export declare const fromEnvSigningName: ({
  logger,
  signingName,
}?: FromEnvSigningNameInit) => TokenIdentityProvider;
