import { SSOToken } from "@smithy/shared-ini-file-loader";
/**
 * Writes SSO token to file based on filepath computed from ssoStartUrl or session name.
 */
export declare const writeSSOTokenToFile: (id: string, ssoToken: SSOToken) => Promise<void>;
