import {
  CredentialProviderOptions,
  TokenIdentity,
  TokenIdentityProvider,
} from "@aws-sdk/types";
export interface FromStaticInit extends CredentialProviderOptions {
  token?: TokenIdentity;
}
export declare const fromStatic: ({
  token,
  logger,
}: FromStaticInit) => TokenIdentityProvider;
